PrintifyProductsApi class

API for communicating with any product related calls.

Constructors

PrintifyProductsApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteProductById({required String baseUrl, required String productId}) Future<PrintifyBaseResponse>
Deletes a product with productId.
getAdminSingleProductById({required String baseUrl, required String productId}) Future<PrintifyGetShopSingleProductResponse>
Gets a specific product by its productId.
getAllProducts({required String baseUrl}) Future<PrintifyGetShopProductsResponse>
Gets all products from Printify.
getMonthlyDealsProducts({required String baseUrl}) Future<PrintifyWeeklyDealsModel>
Gets all products that are on monthly sale.
getPairsWellWith({required String baseUrl, required String productId}) Future<PrintifyGetPairedProducts>
Gets the Pairs Well With for productId.
getProductsByPage({required String baseUrl, required int pageNumber, required int pageLimit}) Future<PrintifyGetShopProductsResponse>
Get all products by pageNumber with a pageLimit.
getProductsBySearchText({required String baseUrl, required String searchText}) Future<PrintifyProductListModel>
Gets all products with the searchText in the title.
getRelatedProducts({required String baseUrl, required String productId}) Future<PrintifyGetRelatedProducts>
Gets random 4 products that relate to this productId.
getSingleProductById({required String baseUrl, required String productId}) Future<PrintifyGetShopSingleProductResponse>
Gets a specifi product by its productId.
getUserPrivateDesigns({required String baseUrl, required String userId}) Future<PrintifyProductListModel>
Publishes productId to the store.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publishProduct({required String baseUrl, required String productId}) Future<PrintifyGetShopProductsResponse>
Publishes productId to the store.
toString() String
A string representation of this object.
inherited
updateProduct({required String baseUrl, required String articleId, required PrintifyUpdateProductRequest request}) Future<PrintifyProductModel>
Updates a product with articleId.

Operators

operator ==(Object other) bool
The equality operator.
inherited