PrintifyOrderLineItem class

Constructors

PrintifyOrderLineItem({required String? product_id, required int? quantity, required int? variant_id, int? print_provider_id, int? cost, int? shipping_cost, String? status, String? sent_to_production_at, String? fulfilled_at, Map<String, dynamic>? metadata})

Properties

cost int?
final
fulfilled_at String?
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
final
final
product_id String?
final
quantity int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sent_to_production_at String?
final
shipping_cost int?
final
status String?
final
variant_id int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) PrintifyOrderLineItem