PrintifyOrderRequest class

This resource could be used, to create a new order

Constructors

PrintifyOrderRequest({String? external_id, String? label, List<PrintifyOrderLineItem>? line_items, int? shipping_method, bool? send_shipping_notification, PrintifyAddress? address_to})
This resource could be used, to create a new order

Properties

address_to PrintifyAddress?
final
external_id String?
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
line_items List<PrintifyOrderLineItem>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
send_shipping_notification bool?
final
shipping_method int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) PrintifyOrderRequest