PrintifyPrintAreaModel class

Annotations
  • @freezed

Constructors

PrintifyPrintAreaModel({List<int>? variant_ids, String? font_color, String? font_family, List<PrintifyPrintAreaPlaceholderModel>? placeholders})
factory
PrintifyPrintAreaModel.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $PrintifyPrintAreaModelCopyWith<PrintifyPrintAreaModel>
no setterinherited
font_color String?
no setterinherited
font_family String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
placeholders List<PrintifyPrintAreaPlaceholderModel>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variant_ids List<int>?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited