PrintifyShipmentModel class

Constructors

PrintifyShipmentModel({String? carrier, String? number, String? url, String? delivered_at})

Properties

carrier String?
final
delivered_at String?
final
hashCode int
The hash code for this object.
no setterinherited
number String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) PrintifyShipmentModel