PrintifyShippingLineItemsModel class

Constructors

PrintifyShippingLineItemsModel({String? product_id, int? variant_id, int? quantity, int? print_provider_id, int? blueprint_id, String? sku})

Properties

blueprint_id int?
final
hashCode int
The hash code for this object.
no setterinherited
final
product_id String?
final
quantity int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sku String?
final
variant_id int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) PrintifyShippingLineItemsModel