PrintifyShopModel class
Constructors
-
PrintifyShopModel({int? id, String? title, String? sales_channel})
-
This resource could be used, to get all created products for your point of sale.
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ int?
-
A unique int identifier for the shop. Each id is unique across the Printify system.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sales_channel
→ String?
-
The name of the associated sales channel. If none are connected it defaults to "disconnected".
final
-
title
→ String?
-
The name of the shop.
final