PrintifyAddress class
Constructors
Properties
- address1 → String?
-
final
- city → String?
-
final
- company → String?
-
final
- country → String?
-
final
- email → String?
-
final
- first_name → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- last_name → String?
-
final
- phone → String?
-
final
- region → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zip → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → PrintifyAddress