PrintifyOrderModel class
This resource could be used, to get all Orders.
Constructors
-
PrintifyOrderModel({String? id, required PrintifyAddress? address_to, required List<
PrintifyOrderLineItem> ? line_items, required int? method, Map<String, dynamic> ? metadata, int? total_price, int? total_shipping, int? total_tax, String? status, List<PrintifyShipmentModel> ? shipments, String? created_at, String? sent_to_production_at, String? fulfilled_at}) - This resource could be used, to get all Orders.
Properties
- address_to → PrintifyAddress?
-
final
- created_at → String?
-
final
- fulfilled_at → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
-
line_items
→ List<
PrintifyOrderLineItem> ? -
final
-
metadata
→ Map<
String, dynamic> ? -
final
- method → int?
-
Method of shipping selected for the order, "1" is for standard shipping and "2" is for express shipping.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sent_to_production_at → String?
-
final
-
shipments
→ List<
PrintifyShipmentModel> ? -
final
- status → String?
-
final
- total_price → int?
-
final
- total_shipping → int?
-
final
- total_tax → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → PrintifyOrderModel