PrintifyProductModel class
Constructors
-
PrintifyProductModel({String? id, String? title, String? description, String? created_at, String? updated_at, bool? visible, bool? is_locked, int? blueprint_id, int? user_id, int? shop_id, int? print_provider_id, bool? twodaydelivery_enabled, bool? isWeeklyDeal = false, double? salePercent, bool? printify_express_eligible, List<
String> ? tags, List<PrintifyProductOptionsModel> ? options, List<PrintifyProductVariantModel> ? variants, List<PrintifyProductImageModel> ? images, List<PrintifyPrintAreaModel> ? print_areas, List<PrintifyPrintDetailModel> ? print_details, List<PrintifySalesChannelPropertyModel> ? sales_channel_properties, List<PrintifyProductCustomVariantModel> ? customVariants, int? pageViews, bool? isLinked = false, bool? isPrivateDesign = false, bool? isOnSale = false}) - This resource could be used, to get all created products for your point of sale.
Properties
- blueprint_id → int?
-
final
- created_at → String?
-
final
-
customVariants
→ List<
PrintifyProductCustomVariantModel> ? -
final
- description → String?
-
final
- docId ↔ String?
-
Unique identifier for the Firebase Doc ID.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
A unique string identifier for the product. Each id is unique across the Printify system.
final
-
images
→ List<
PrintifyProductImageModel> ? -
final
- is_locked → bool?
-
final
- isFavorited ↔ bool
-
getter/setter pair
- isLinked ↔ bool?
-
getter/setter pair
- isOnSale ↔ bool?
-
getter/setter pair
- isPrivateDesign ↔ bool?
-
getter/setter pair
- isWeeklyDeal ↔ bool?
-
getter/setter pair
- numOfReviews ↔ int
-
getter/setter pair
-
options
→ List<
PrintifyProductOptionsModel> ? -
final
- pageViews ↔ int?
-
getter/setter pair
-
print_areas
→ List<
PrintifyPrintAreaModel> ? -
final
-
print_details
→ List<
PrintifyPrintDetailModel> ? -
final
- print_provider_id → int?
-
final
- printify_express_eligible → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salePercent ↔ double?
-
getter/setter pair
-
sales_channel_properties
→ List<
PrintifySalesChannelPropertyModel> ? -
final
- shop_id → int?
-
final
-
final
- title → String?
-
final
- twodaydelivery_enabled → bool?
-
final
- updated_at → String?
-
final
- user_id → int?
-
final
-
variants
→ List<
PrintifyProductVariantModel> ? -
final
- visible → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → PrintifyProductModel